@@ -58,9 +58,9 @@ class TestRestructuredtextLint(TestCase):
         self.assertEqual(actual_errors[0].message, 'Title underline too short.')
 
     def test_encoding_utf8(self):
-        """A document with utf-8 characters is valid."""
+        """A document with utf-8 characters can be linted."""
         filepath = os.path.join(_dir, 'test_files', 'utf8.rst')
-        errors = restructuredtext_lint.lint_file(filepath, encoding='utf-8')
+        errors = restructuredtext_lint.lint_file(filepath)
         self.assertEqual(errors, [])
 
     def test_second_heading_short_line_number(self):
